
# README for Gene Expression and Biomarker Utility in Postmortem Samples [supporting dataset]  
Civil Aerospace Medical Institute, Federal Aviation Administration, U.S. Department of Transportation (USDOT)  
2024-04-10  
## Links to Dataset  
Dataset Archive Link: <https://doi.org/10.21949/1530703>
## Summary of Dataset  

This study assesses the suitability of aviation accident autopsy samples as RNA sequencing input and for detecting gene expression differences between THC-positive and THC-negative samples. Postmortem brain, lung, muscle, and blood samples were collected from 57 aviation accident fatalities and comparisons were made between each tissue based on the presence or absence of THC or its primary or secondary metabolites (28 positive, 29 negative). RNA was extracted, and global transcriptional analysis was performed using total RNA-Seq. Twenty-two genes in lung (18 of which had Entrez annotation data) and four in muscle showed significant differential gene expression between THC-positive and THC-negative samples. It is possible that the observed expression patterns between the THC-positive and THC-negative groups were induced by smoking and not by THC, as many of the observed genes were also reported in the literature to change in response to smoking. Cannabis use is often accompanied by other substance use, and evidence of co-use was observed among some subjects. Therefore, we cannot state conclusively that the observed differences between the THC-positive and THC-negative groups were due solely to THC consumption, only that significant differences exist when the subject groups are so segregated. Regardless, this study is the first of its kind in reporting RNA-Seq data from postmortem tissues collected from aviation accident victims and that said data are of sufficient quality to derive significant differences between subject groups.  

## Tables of Contents  
##### A. General Information  
##### B. Sharing/Access & Policies Information  
##### C. Data and Related Files Overview  
##### D. Methodological Information  
##### E. Data-Specific Information for: Gene Expression and Biomarker Utility in Postmortem Samples [supporting dataset]  
##### F. Update Log  
## A. General Information  

**Title of Dataset:**  Gene Expression and Biomarker Utility in Postmortem Samples [supporting dataset]

**Description of the Dataset:** This study assesses the suitability of aviation accident autopsy samples as RNA sequencing input and for detecting gene expression differences between THC-positive and THC-negative samples. Postmortem brain, lung, muscle, and blood samples were collected from 57 aviation accident fatalities and comparisons were made between each tissue based on the presence or absence of THC or its primary or secondary metabolites (28 positive, 29 negative). RNA was extracted, and global transcriptional analysis was performed using total RNA-Seq. Twenty-two genes in lung (18 of which had Entrez annotation data) and four in muscle showed significant differential gene expression between THC-positive and THC-negative samples. It is possible that the observed expression patterns between the THC-positive and THC-negative groups were induced by smoking and not by THC, as many of the observed genes were also reported in the literature to change in response to smoking. Cannabis use is often accompanied by other substance use, and evidence of co-use was observed among some subjects. Therefore, we cannot state conclusively that the observed differences between the THC-positive and THC-negative groups were due solely to THC consumption, only that significant differences exist when the subject groups are so segregated. Regardless, this study is the first of its kind in reporting RNA-Seq data from postmortem tissues collected from aviation accident victims and that said data are of sufficient quality to derive significant differences between subject groups.

**Dataset Archive Link:** <https://doi.org/10.21949/1530703>  

**Report Archive Link:** <https://doi.org/10.21949/1529631>  

**Data Management Plan Archive Link:** <https://doi.org/10.48321/D1362Q>  

The public summary-level phenotype data may be browsed at the dbGaP study report page at <https://www.ncbi.nlm.nih.gov/projects/gap/cgi-bin/study.cgi?study_id=phs003546.v1.p1>  

**Authorship Information:**  

>  *Principal Data Creator or Data Manager Contact Information*  
>  Name: Scott J. Nicholson [0000-0002-2201-744X](https://orcid.org/0000-0002-2201-744X)  
>  Institution: Federal Aviation Administration, Civil Aerspace Medical Institute (CAMI)  
>  Address: 6500 S Macarthur BLVD HQ Room BS 13, Oklahoma City, OK 73169  
>  Email: <scott.nicholson@faa.gov>  

>  *Data Distributor Contact Information*  
>  Name: Christopher J. Tracy [0000-0002-4532-3327)(https://orcid.org/0000-0002-4532-3327)  
>  Institution: Federal Aviation Administration, Civil Aerspace Medical Institute (CAMI)  
>  Address: 6500 S Macarthur BLVD HQ Room BS 13, Oklahoma City, OK 73169  
>  Email: <christopher.J.Tracy@faa.gov>  

>  *Additional Author*  
>  Name: David C. Hutchings [0009-0008-4575-8444](https://orcid.org/0009-0008-4575-8444)  
>  Institution: Federal Aviation Administration, Civil Aerspace Medical Institute (CAMI)  
>  Address: 6500 S Macarthur BLVD HQ Room BS 13, Oklahoma City, OK 73169  

>  *Additional Author*  
>  Name: Susan K. Munster [0000-0002-3223-0076](https://orcid.org/0000-0002-3223-0076)  
>  Institution: Federal Aviation Administration, Civil Aerspace Medical Institute (CAMI)  
>  Address: 6500 S Macarthur BLVD HQ Room BS 13, Oklahoma City, OK 73169  

>  *Additional Author*  
>  Name: Vicky L. White [0009-0007-1164-5233](https://orcid.org/0009-0007-1164-5233)  
>  Institution: Federal Aviation Administration, Civil Aerspace Medical Institute (CAMI)  
>  Address: 6500 S Macarthur BLVD HQ Room BS 13, Oklahoma City, OK 73169  

**Date of data collection and update interval:** 9/30/2019 until 9/30/2022  

**Geographic location of data collection:** United States  

**Information about funding sources that supported the collection of the data:** This research was funded by the Federal Aviation Administration. The authors declare that they have no competing interests.  

## B. Sharing/Access and Policies Information  

**Recommended citation for the data:**  

>  United States. Department of Transportation. Federal Aviation Administration. Office of Aviation. Civil Aerospace Medical Institute (2024). Gene Expression and Biomarker Utility in Postmortem Samples [supporting dataset]. <https://doi.org/10.21949/1530703>  

**Licenses/restrictions placed on the data:** This document is disseminated under the sponsorship of the U.S. Department of Transportation in the interest of information exchange. The United States Government assumes no liability for the contents thereof.  

**Was data derived from another source?:** No  

This document was created to meet the requirements enumerated in the U.S. Department of Transportation's `Plan to Increase Public Access to the Results of Federally-Funded Scientific Research Version 1.1`(https://doi.org/10.21949/1520559) and `Guidelines Suggested by the DOT Public Access website`(https://doi.org/10.21949/1503647), in effect and current as of December 03, 2020.  

 
## C. Data and Related Files Overview  

File List for the 96986_DATASET.zip  

>  1. Filename: supplemental_file_1_FAA_GEN_alignment_pipeline_gencode_v1.2_PM.sh  
>  Short Description:  Alignment and quality control pipeline code in the form of a bash script   

>  2. Filename: supplemental_file_2_gencode_PM_DESeq2_analysis_untrimmed.nb.html 
>  Short Description:  HTML accessible notebook of the above R Markdown document  

>  3. Filename: supplemental_file_2_gencode_PM_DESeq2_analysis_untrimmed.Rmd  
>  Short Description:  R Markdown document containing the full DGEA code, supplemental files 3-8 are required  

>  4. Filename: supplemental_file_3_metadata_untrimmed.csv  
>  Short Description:  Tissue and THC classification for all samples along with RNA extraction metrics  

>  5. Filename: supplemental_file_4_metadata_PB_untrimmed.csv  
>  Short Description:  Tissue and THC classification for PB samples only  

>  6. Filename: supplemental_file_5_metadata_PL_untrimmed.csv 
>  Short Description:  Tissue and THC classification for PL samples only 

>  7. Filename: supplemental_file_6_metadata_PM_untrimmed.csv  
>  Short Description:  Tissue and THC classification for PM samples only 

>  8. Filename: supplemental_file_7_metadata_PS_untrimmed.csv  
>  Short Description:  Tissue and THC classification for PS samples only  

>  9. Filename: supplemental_file_8_PM_gencode_featurecounts.Rmatrix.txt  
>  Short Description:  Matrix containing featurecounts data for all samples  

>  10. Filename: supplemental_file_9_PM_taxonomy_plots.nb.html  
>  Short Description:  HTML accessible notebook of the above R Markdown document  

>  11. Filename: supplemental_file_9_PM_taxonomy_plots.Rmd  
>  Short Description:  R Markdown document containing the full taxonomy analysis code, supplemental files 10-14 are required   

>  12. Filename: supplemental_file_10_gencode_PM_PB_species_kraken_summary 
>  Short Description:  Species level kraken results summary for PB samples  

>  13. Filename: supplemental_file_11_gencode_PM_PL_species_kraken_summary  
>  Short Description:  Species level kraken results summary for PL samples  

>  14. Filename: supplemental_file_12_gencode_PM_PM_species_kraken_summary  
>  Short Description:  Species level kraken results summary for PM samples  

>  15. Filename: supplemental_file_13_gencode_PM_PS_species_kraken_summary  
>  Short Description:  Species level kraken results summary for PS samples  

>  16. Filename: supplemental_file_14_star_alignment_plot.tsv  
>  Short Description:  Alignment read counts for all samples  

## D. Methodological Information  

**Description of methods used for collection/generation of data:** All research was conducted with the approval of the FAA Institutional Review Board. A waiver of consent exists for specimens collected from fatal aviation accident victims, as a human subject, as defined by 49 C.F.R. §11.102(e)(1)(i), is “a living individual about whom an investigator conducting research obtains [...] biospecimens through [...] interaction with the individual, and [...] analyzes [...] the biospecimens.” As research samples for this study were only collected from deceased individuals, individual or familial consent was not required for sample collection. All personally identifiable information was removed from these samples, and RNA-Seq data are deposited in the limited-access Database of Genotypes and Phenotypes.  

**Instrument or software-specific information needed to interpret the data:** 

*For the Shell Script:*  
Open the .SH file using Notepad++  
- FastQC-0.12.1
- CutAdapt-4.3; installed through Conda, uses the "cutadapt" environment
- Kraken v1.1.1, Kraken2 v2.1.2, and Bracken v2.8; installed through Conda, uses the "kraken" environment
- KronaTools-2.8.1 requires running scripts in the KronaTools installation folder to update Taxonomy and Accessions prior to first use
- STAR-2.7.10.b
- Samtools-1.17
- QualiMap v.2.2.2d; installed through Conda, uses the "qualimap" environment deepTools-3.5.1; installed through Conda, uses the "deeptools" environment
- Preseq v3.2.0; installed through Conda, uses the "preseq" environment
- RNA-SeQC v2.3.5; installed through Conda, uses the "rna-seqc" environment requires a collapsed GTF file generated using the "bx-python" environment
- RSeQC v5.0.1; installed through Conda, uses the "rseqc" environment requires a BED file generated using either the "bedops" or "ucsc" environment (use "ucsc" for Ensembl/Gencode GTFs)
- Picard v2.27.5; installed throuhg Conda, uses the "picard" environment requires a refFlat file generated using the "ucsc" environment and then physically edited in LibreOffice Calc requires an rRNA intervals file physically edited in Text Editor
- Salmon v1.10.1; installed through Conda, uses the "salmon" environment
- Rsem v1.3.3; installed through Conda, uses the "rsem" environment
- Subread-2.0.4
- MultiQC-1.14; installed through Conda, uses the "multiqc" environment

Other packages that may be implemented in the future: 
- FastQ-Screen v0.15.2; Conda  

*For the R Studio File*
Open the .RMD file in RStudio

*For the CSV, TSV, and TXT Files*
Open CSVs, TSVs, and TXT files in Notepad++  

*For the HTML File*
Open the HTML file in your default web browser  

## E. Data-Specific Information  

1. supplemental_file_3_metadata_untrimmed.csv  
- Number of variables (columns): 7  
- Number of cases/rows: 202  
- Each row represents: 1 Sample  
- Data Dictionary/Variable List: Sample, Tissue, THC, Concentration, A260_280, A260_230. RIN  
- Missing data codes: NA  

2. supplemental_file_4_metadata_PB_untrimmed.csv  
- Number of variables (columns): 3  
- Number of cases/rows: 54  
- Each row represents: Sample  
- Data Dictionary/Variable List: Sample, Tissue, THC
- Missing data codes: No missing data codes  

3. supplemental_file_5_metadata_PL_untrimmed.csv  
- Number of variables (columns): 3  
- Number of cases/rows: 53  
- Each row represents: Sample  
- Data Dictionary/Variable List: Sample, Tissue, THC  
- Missing data codes: No missing data codes  

4. supplemental_file_6_metadata_PM_untrimmed.csv  
- Number of variables (columns): 3  
- Number of cases/rows: 54  
- Each row represents: Sample  
- Data Dictionary/Variable List: Sample, Tissue, THC  
- Missing data codes: No missing data codes  

5. supplemental_file_7_metadata_PS_untrimmed.csv  
- Number of variables (columns): 3  
- Number of cases/rows: 44  
- Each row represents: Sample  
- Data Dictionary/Variable List: Sample, Tissue, THC  
- Missing data codes: No missing data codes  

## F. Update Log  

This README.txt file was originally created on 2024-03-07 by Peyton Tvrdy ([0000-0002-9720-4725](https://orcid.org/0000-0002-9720-4725)), Data Management and Data Curation Fellow, National Transportation Library <peyton.tvrdy.ctr@dot.gov>  
 
2024-04-10: Original file created  